@@ -1,6 +1,6 @@
 """Module for the automations and business logic of XKNX."""
+# flake8: noqa
 from .stateupdater import StateUpdater
 from .telegram_queue import TelegramQueue
 from .config import Config
-from .globals import Globals
 from .value_reader import ValueReader
