@@ -6,9 +6,12 @@ Module for reading configfiles (xknx.yaml).
 """
 
 import yaml
-from xknx.knx import Address, AddressType
-from xknx.devices import Notification, BinarySensor, Climate, \
-    Time, Light, Switch, Cover, Sensor
+
+from xknx.devices import (
+    BinarySensor, Climate, Cover, DateTime, ExposeSensor, Light, Notification,
+    Scene, Sensor, Switch)
+from xknx.exceptions import XKNXException
+from xknx.knx import PhysicalAddress
 
 
 class Config:
@@ -21,22 +24,29 @@ class Config:
     def read(self, file='xknx.yaml'):
         """Read config."""
         self.xknx.logger.debug("Reading %s", file)
-        with open(file, 'r') as filehandle:
-            doc = yaml.load(filehandle)
-            self.parse_general(doc)
-            self.parse_groups(doc)
+        try:
+            with open(file, 'r') as filehandle:
+                doc = yaml.load(filehandle)
+                self.parse_general(doc)
+                self.parse_groups(doc)
+        except FileNotFoundError as ex:
+            self.xknx.logger.error("Error while reading %s: %s", file, ex)
 
     def parse_general(self, doc):
         """Parse the general section of xknx.yaml."""
         if "general" in doc:
             if "own_address" in doc["general"]:
                 self.xknx.own_address = \
-                    Address(doc["general"]["own_address"],
-                            AddressType.PHYSICAL)
+                    PhysicalAddress(doc["general"]["own_address"])
 
     def parse_groups(self, doc):
         """Parse the group section of xknx.yaml."""
         for group in doc["groups"]:
+            self.parse_group(doc, group)
+
+    def parse_group(self, doc, group):
+        """Parse a group entry of xknx.yaml."""
+        try:
             if group.startswith("light"):
                 self.parse_group_light(doc["groups"][group])
             elif group.startswith("switch"):
@@ -45,14 +55,20 @@ class Config:
                 self.parse_group_cover(doc["groups"][group])
             elif group.startswith("climate"):
                 self.parse_group_climate(doc["groups"][group])
-            elif group.startswith("time"):
-                self.parse_group_time(doc["groups"][group])
+            elif group.startswith("datetime"):
+                self.parse_group_datetime(doc["groups"][group])
             elif group.startswith("sensor"):
                 self.parse_group_sensor(doc["groups"][group])
+            elif group.startswith("expose_sensor"):
+                self.parse_group_expose_sensor(doc["groups"][group])
             elif group.startswith("binary_sensor"):
                 self.parse_group_binary_sensor(doc["groups"][group])
             elif group.startswith("notification"):
                 self.parse_group_notification(doc["groups"][group])
+            elif group.startswith("scene"):
+                self.parse_group_scene(doc["groups"][group])
+        except XKNXException as ex:
+            self.xknx.logger.error("Error while reading config file: Could not parse %s: %s", group, ex)
 
     def parse_group_light(self, entries):
         """Parse a light section of xknx.yaml."""
@@ -98,15 +114,17 @@ class Config:
                 entry,
                 entries[entry])
             self.xknx.devices.add(climate)
+            if climate.mode is not None:
+                self.xknx.devices.add(climate.mode)
 
-    def parse_group_time(self, entries):
-        """Parse a time section of xknx.yaml."""
+    def parse_group_datetime(self, entries):
+        """Parse a datetime section of xknx.yaml."""
         for entry in entries:
-            time = Time.from_config(
+            datetime = DateTime.from_config(
                 self.xknx,
                 entry,
                 entries[entry])
-            self.xknx.devices.add(time)
+            self.xknx.devices.add(datetime)
 
     def parse_group_sensor(self, entries):
         """Parse a sensor section of xknx.yaml."""
@@ -117,6 +135,15 @@ class Config:
                 entries[entry])
             self.xknx.devices.add(sensor)
 
+    def parse_group_expose_sensor(self, entries):
+        """Parse a exposed sensor section of xknx.yaml."""
+        for entry in entries:
+            expose_sensor = ExposeSensor.from_config(
+                self.xknx,
+                entry,
+                entries[entry])
+            self.xknx.devices.add(expose_sensor)
+
     def parse_group_notification(self, entries):
         """Parse a sensor section of xknx.yaml."""
         for entry in entries:
@@ -125,3 +152,12 @@ class Config:
                 entry,
                 entries[entry])
             self.xknx.devices.add(notification)
+
+    def parse_group_scene(self, entries):
+        """Parse a scene section of xknx.yaml."""
+        for entry in entries:
+            scene = Scene.from_config(
+                self.xknx,
+                entry,
+                entries[entry])
+            self.xknx.devices.add(scene)
