@@ -13,18 +13,20 @@ class StateUpdater():
         self.xknx = xknx
         self.timeout = timeout
         self.start_timeout = start_timeout
+        self.run_forever = True
+        self.run_task = None
 
-    @asyncio.coroutine
-    def start(self):
+    async def start(self):
         """Start StateUpdater."""
-        self.xknx.loop.create_task(
+        self.run_task = self.xknx.loop.create_task(
             self.run())
 
-    @asyncio.coroutine
-    def run(self):
+    async def run(self):
         """Worker thread. Endless loop for updating states."""
-        yield from asyncio.sleep(self.start_timeout)
+        await asyncio.sleep(self.start_timeout)
         self.xknx.logger.debug("Starting StateUpdater")
         while True:
-            yield from self.xknx.devices.sync()
-            yield from asyncio.sleep(self.timeout)
+            await self.xknx.devices.sync()
+            await asyncio.sleep(self.timeout)
+            if not self.run_forever:
+                break
