@@ -1,5 +1,4 @@
 """Module for handling commands which may be attached to BinarySensor class."""
-import asyncio
 
 
 class ActionBase():
@@ -36,11 +35,9 @@ class ActionBase():
             return True
         return False
 
-    @asyncio.coroutine
-    def execute(self):
+    async def execute(self):
         """Execute action. To be overwritten in derived classes."""
-        # pylint: disable=no-self-use
-        pass
+        self.xknx.logger.info("Execute not implemented for %s", self.__class__.__name__)
 
     def __str__(self):
         """Return object as readable string."""
@@ -80,14 +77,17 @@ class Action(ActionBase):
                    method=method,
                    counter=counter)
 
-    @asyncio.coroutine
-    def execute(self):
+    async def execute(self):
         """Execute action."""
-        yield from self.xknx.devices[self.target].do(self.method)
+        if self.target is not None:
+            if self.target not in self.xknx.devices:
+                self.xknx.logger.warning("Unknown device %s witin action %s.", self.target, self)
+                return
+            await self.xknx.devices[self.target].do(self.method)
 
     def __str__(self):
         """Return object as readable string."""
-        return '<Action target="{1}" method="{2}" {3}/>' \
+        return '<Action target="{0}" method="{1}" {2}/>' \
             .format(self.target, self.method, super(Action, self).__str__())
 
 
@@ -104,10 +104,9 @@ class ActionCallback(ActionBase):
         super(ActionCallback, self).__init__(xknx, hook, counter)
         self.callback = callback
 
-    @asyncio.coroutine
-    def execute(self):
+    async def execute(self):
         """Execute callback."""
-        yield from self.callback()
+        await self.callback()
 
     def __str__(self):
         """Return object as readable string."""
