@@ -8,11 +8,13 @@ A binary sensor can be:
 
 A BinarySensor may also have Actions attached which are executed after state was changed.
 """
-import time
 import asyncio
+import time
 from enum import Enum
-from xknx.knx import Address
+
 from xknx.exceptions import CouldNotParseTelegram
+from xknx.knx import DPTBinary, GroupAddress
+
 from .action import Action
 from .device import Device
 
@@ -36,23 +38,29 @@ class BinarySensor(Device):
                  xknx,
                  name,
                  group_address=None,
+                 group_address_state=None,
                  device_class=None,
                  significant_bit=1,
+                 reset_after=None,
                  actions=None,
                  device_updated_cb=None):
         """Initialize BinarySensor class."""
         # pylint: disable=too-many-arguments
-        Device.__init__(self, xknx, name, device_updated_cb)
+        super(BinarySensor, self).__init__(xknx, name, device_updated_cb)
         if isinstance(group_address, (str, int)):
-            group_address = Address(group_address)
+            group_address = GroupAddress(group_address)
+        if isinstance(group_address_state, (str, int)):
+            group_address_state = GroupAddress(group_address_state)
         if not isinstance(significant_bit, int):
             raise TypeError()
         if actions is None:
             actions = []
 
         self.group_address = group_address
+        self.group_address_state = group_address_state
         self.device_class = device_class
         self.significant_bit = significant_bit
+        self.reset_after = reset_after
         self.state = BinarySensorState.OFF
         self.actions = actions
 
@@ -65,6 +73,8 @@ class BinarySensor(Device):
         """Initialize object from configuration structure."""
         group_address = \
             config.get('group_address')
+        group_address_state = \
+            config.get('group_address_state')
         device_class = \
             config.get('device_class')
         significant_bit = \
@@ -79,32 +89,34 @@ class BinarySensor(Device):
         return cls(xknx,
                    name,
                    group_address=group_address,
+                   group_address_state=group_address_state,
                    device_class=device_class,
                    significant_bit=significant_bit,
                    actions=actions)
 
     def has_group_address(self, group_address):
         """Test if device has given group address."""
-        return self.group_address == group_address
+        return group_address in [self.group_address, self.group_address_state]
 
     def state_addresses(self):
         """Return group addresses which should be requested to sync state."""
-        return [self.group_address, ]
+        if self.group_address_state is not None:
+            return [self.group_address_state, ]
+        return []
 
-    @asyncio.coroutine
-    def _set_internal_state(self, state):
+    async def _set_internal_state(self, state):
         """Set the internal state of the device. If state was changed after update hooks and connected Actions are executed."""
         if state != self.state:
             self.state = state
-            counter = self.get_counter(state)
-            yield from self.after_update()
+            counter = self.bump_and_get_counter(state)
+            await self.after_update()
 
             for action in self.actions:
                 if action.test_if_applicable(self.state, counter):
-                    yield from action.execute()
+                    await action.execute()
 
-    def get_counter(self, state):
-        """Return the number of times a state was set to the same value within CONTEXT_TIMEOUT."""
+    def bump_and_get_counter(self, state):
+        """Bump counter and return the number of times a state was set to the same value within CONTEXT_TIMEOUT."""
         def within_same_context():
             """Check if state change was within same context (e.g. 'Button was pressed twice')."""
             if self.last_set is None:
@@ -130,18 +142,19 @@ class BinarySensor(Device):
             self.count_set_off = 1
         return 1
 
-    @asyncio.coroutine
-    def process(self, telegram):
-        """Process incoming telegram."""
-        bit_masq = 1 << (self.significant_bit-1)
-        binary_value = telegram.payload.value & bit_masq != 0
+    async def process_group_write(self, telegram):
+        """Process incoming GROUP WRITE telegram."""
+        if not isinstance(telegram.payload, DPTBinary):
+            raise CouldNotParseTelegram("invalid payload", payload=telegram.payload, device_name=self.name)
 
-        if binary_value == 0:
-            yield from self._set_internal_state(BinarySensorState.OFF)
-        elif binary_value == 1:
-            yield from self._set_internal_state(BinarySensorState.ON)
+        bit_masq = 1 << (self.significant_bit-1)
+        if telegram.payload.value & bit_masq == 0:
+            await self._set_internal_state(BinarySensorState.OFF)
         else:
-            raise CouldNotParseTelegram()
+            await self._set_internal_state(BinarySensorState.ON)
+            if self.reset_after is not None:
+                await asyncio.sleep(self.reset_after/1000)
+                await self._set_internal_state(BinarySensorState.OFF)
 
     def is_on(self):
         """Return if binary sensor is 'on'."""
@@ -154,7 +167,7 @@ class BinarySensor(Device):
     def __str__(self):
         """Return object as readable string."""
         return '<BinarySensor group_address="{0}" name="{1}" state="{2}"/>' \
-            .format(self.group_address, self.name, self.state)
+            .format(self.group_address.__repr__(), self.name, self.state)
 
     def __eq__(self, other):
         """Equal operator."""
