@@ -7,11 +7,11 @@ It provides functionality for
 * reading the current state from KNX bus.
 * Cover will also predict the current position.
 """
-import asyncio
 from .device import Device
+from .remote_value_scaling import RemoteValueScaling
+from .remote_value_step import RemoteValueStep
+from .remote_value_updown import RemoteValueUpDown
 from .travelcalculator import TravelCalculator
-from .remote_value import RemoteValueScaling5001, RemoteValueUpDown1008, \
-    RemoteValueStep1007
 
 
 class Cover(Device):
@@ -19,6 +19,7 @@ class Cover(Device):
 
     # pylint: disable=too-many-instance-attributes
     # pylint: disable=too-many-public-methods
+    # pylint: disable=too-many-locals
 
     # Average typical travel time of a cover
     DEFAULT_TRAVEL_TIME_DOWN = 22
@@ -40,33 +41,43 @@ class Cover(Device):
                  device_updated_cb=None):
         """Initialize Cover class."""
         # pylint: disable=too-many-arguments
-        Device.__init__(self, xknx, name, device_updated_cb)
+        super(Cover, self).__init__(xknx, name, device_updated_cb)
 
-        self.updown = RemoteValueUpDown1008(
+        self.updown = RemoteValueUpDown(
             xknx,
             group_address_long,
+            device_name=self.name,
             after_update_cb=self.after_update,
             invert=invert_position)
 
-        self.step = RemoteValueStep1007(
+        self.step = RemoteValueStep(
             xknx,
             group_address_short,
+            device_name=self.name,
             after_update_cb=self.after_update,
             invert=invert_position)
 
-        self.position = RemoteValueScaling5001(
+        position_range_from = 0 if invert_position else 100
+        position_range_to = 100 if invert_position else 0
+        self.position = RemoteValueScaling(
             xknx,
             group_address_position,
             group_address_position_state,
+            device_name=self.name,
             after_update_cb=self.after_update,
-            invert=invert_position)
+            range_from=position_range_from,
+            range_to=position_range_to)
 
-        self.angle = RemoteValueScaling5001(
+        angle_range_from = 0 if invert_angle else 100
+        angle_range_to = 100 if invert_angle else 0
+        self.angle = RemoteValueScaling(
             xknx,
             group_address_angle,
             group_address_angle_state,
+            device_name=self.name,
             after_update_cb=self.after_update,
-            invert=invert_angle)
+            range_from=angle_range_from,
+            range_to=angle_range_to)
 
         self.travel_time_down = travel_time_down
         self.travel_time_up = travel_time_up
@@ -94,6 +105,10 @@ class Cover(Device):
             config.get('travel_time_down', cls.DEFAULT_TRAVEL_TIME_DOWN)
         travel_time_up = \
             config.get('travel_time_up', cls.DEFAULT_TRAVEL_TIME_UP)
+        invert_position = \
+            config.get('invert_position', False)
+        invert_angle = \
+            config.get('invert_angle', False)
 
         return cls(
             xknx,
@@ -105,7 +120,9 @@ class Cover(Device):
             group_address_angle=group_address_angle,
             group_address_angle_state=group_address_angle_state,
             travel_time_down=travel_time_down,
-            travel_time_up=travel_time_up)
+            travel_time_up=travel_time_up,
+            invert_position=invert_position,
+            invert_angle=invert_angle)
 
     def has_group_address(self, group_address):
         """Test if device has given group address."""
@@ -117,7 +134,7 @@ class Cover(Device):
     def __str__(self):
         """Return object as readable string."""
         return '<Cover name="{0}" ' \
-            'updown"{1}" ' \
+            'updown="{1}" ' \
             'step="{2}" ' \
             'position="{3}" ' \
             'angle="{4}" '\
@@ -132,64 +149,57 @@ class Cover(Device):
                 self.travel_time_down,
                 self.travel_time_up)
 
-    @asyncio.coroutine
-    def set_down(self):
+    async def set_down(self):
         """Move cover down."""
-        yield from self.updown.down()
+        await self.updown.down()
         self.travelcalculator.start_travel_down()
 
-    @asyncio.coroutine
-    def set_up(self):
+    async def set_up(self):
         """Move cover up."""
-        yield from self.updown.up()
+        await self.updown.up()
         self.travelcalculator.start_travel_up()
 
-    @asyncio.coroutine
-    def set_short_down(self):
+    async def set_short_down(self):
         """Move cover short down."""
-        yield from self.step.increase()
+        await self.step.increase()
 
-    @asyncio.coroutine
-    def set_short_up(self):
+    async def set_short_up(self):
         """Move cover short up."""
-        yield from self.step.decrease()
+        await self.step.decrease()
 
-    @asyncio.coroutine
-    def stop(self):
+    async def stop(self):
         """Stop cover."""
         # Thats the KNX way of doing this. electrical engineers ... m-)
-        yield from self.step.increase()
+        await self.step.increase()
         self.travelcalculator.stop()
 
-    @asyncio.coroutine
-    def set_position(self, position):
+    async def set_position(self, position):
         """Move cover to a desginated postion."""
         # No direct positioning group address defined
         if not self.position.group_address:
             current_position = self.current_position()
             if position < current_position:
-                yield from self.updown.down()
+                await self.updown.down()
             elif position > current_position:
-                yield from self.updown.up()
+                await self.updown.up()
             self.travelcalculator.start_travel(position)
             return
 
-        yield from self.position.set(position)
+        await self.position.set(position)
         self.travelcalculator.start_travel(position)
 
-    @asyncio.coroutine
-    def set_angle(self, angle):
+    async def set_angle(self, angle):
         """Move cover to designated angle."""
         if not self.supports_angle:
+            self.xknx.logger.warning('Angle not supported for device %s', self.get_name())
             return
-        yield from self.angle.set(angle)
-        yield from self.after_update()
+        await self.angle.set(angle)
+        await self.after_update()
 
-    @asyncio.coroutine
-    def auto_stop_if_necessary(self):
+    async def auto_stop_if_necessary(self):
         """Do auto stop if necessary."""
         # If device does not support auto_positioning,
-        # we have to ttop the device when position is reached.
+        # we have to stop the device when position is reached.
         # unless device was traveling to fully open
         # or fully closed state
         if (
@@ -197,19 +207,18 @@ class Cover(Device):
                 self.position_reached() and
                 not self.is_open() and
                 not self.is_closed()):
-            yield from self.stop()
+            await self.stop()
 
-    @asyncio.coroutine
-    def do(self, action):
+    async def do(self, action):
         """Execute 'do' commands."""
         if action == "up":
-            yield from self.set_up()
+            await self.set_up()
         elif action == "short_up":
-            yield from self.set_short_up()
+            await self.set_short_up()
         elif action == "down":
-            yield from self.set_down()
+            await self.set_down()
         elif action == "short_down":
-            yield from self.set_short_down()
+            await self.set_short_down()
         else:
             self.xknx.logger.warning("Could not understand action %s for device %s", action, self.get_name())
 
@@ -223,15 +232,14 @@ class Cover(Device):
         state_addresses.extend(self.angle.state_addresses())
         return state_addresses
 
-    @asyncio.coroutine
-    def process(self, telegram):
-        """Process incoming telegram."""
-        position_processed = yield from self.position.process(telegram)
+    async def process_group_write(self, telegram):
+        """Process incoming GROUP WRITE telegram."""
+        position_processed = await self.position.process(telegram)
         if position_processed:
             self.travelcalculator.set_position(self.position.value)
-            yield from self.after_update()
+            await self.after_update()
 
-        yield from self.angle.process(telegram)
+        await self.angle.process(telegram)
 
     def current_position(self):
         """Return current position of cover."""
