@@ -3,7 +3,6 @@ Module for handling a vector/array of devices.
 
 More or less an array with devices. Adds some search functionality to find devices.
 """
-import asyncio
 from .device import Device
 
 
@@ -46,6 +45,13 @@ class Devices:
         """Return number of devices within vector."""
         return len(self.__devices)
 
+    def __contains__(self, key):
+        """Return if devices with name 'key' is within devices."""
+        for device in self.__devices:
+            if device.name == key:
+                return True
+        return False
+
     def add(self, device):
         """Add device to devices vector."""
         if not isinstance(device, Device):
@@ -53,14 +59,12 @@ class Devices:
         device.register_device_updated_cb(self.device_updated)
         self.__devices.append(device)
 
-    @asyncio.coroutine
-    def device_updated(self, device):
+    async def device_updated(self, device):
         """Call all registered device updated callbacks of device."""
         for device_updated_cb in self.device_updated_cbs:
-            yield from device_updated_cb(device)
+            await device_updated_cb(device)
 
-    @asyncio.coroutine
-    def sync(self):
+    async def sync(self):
         """Read state of devices from KNX bus."""
         for device in self.__devices:
-            yield from device.sync()
+            await device.sync()
