@@ -6,9 +6,8 @@ It provides functionality for
 * switching 'on' and 'off'.
 * reading the current state from KNX bus.
 """
-import asyncio
 from .device import Device
-from .remote_value import RemoteValueSwitch1001
+from .remote_value_switch import RemoteValueSwitch
 
 
 class Switch(Device):
@@ -22,12 +21,13 @@ class Switch(Device):
                  device_updated_cb=None):
         """Initialize Switch class."""
         # pylint: disable=too-many-arguments
-        Device.__init__(self, xknx, name, device_updated_cb)
+        super(Switch, self).__init__(xknx, name, device_updated_cb)
 
-        self.switch = RemoteValueSwitch1001(
+        self.switch = RemoteValueSwitch(
             xknx,
             group_address,
             group_address_state,
+            device_name=self.name,
             after_update_cb=self.after_update)
 
     @classmethod
@@ -50,25 +50,22 @@ class Switch(Device):
     @property
     def state(self):
         """Return the current switch state of the device."""
-        return self.switch.value == RemoteValueSwitch1001.Value.ON
+        return self.switch.value == RemoteValueSwitch.Value.ON
 
-    @asyncio.coroutine
-    def set_on(self):
+    async def set_on(self):
         """Switch on switch."""
-        yield from self.switch.on()
+        await self.switch.on()
 
-    @asyncio.coroutine
-    def set_off(self):
+    async def set_off(self):
         """Switch off switch."""
-        yield from self.switch.off()
+        await self.switch.off()
 
-    @asyncio.coroutine
-    def do(self, action):
+    async def do(self, action):
         """Execute 'do' commands."""
         if action == "on":
-            yield from self.set_on()
+            await self.set_on()
         elif action == "off":
-            yield from self.set_off()
+            await self.set_off()
         else:
             self.xknx.logger.warning("Could not understand action %s for device %s", action, self.get_name())
 
@@ -76,10 +73,9 @@ class Switch(Device):
         """Return group addresses which should be requested to sync state."""
         return self.switch.state_addresses()
 
-    @asyncio.coroutine
-    def process(self, telegram):
-        """Process incoming telegram."""
-        yield from self.switch.process(telegram)
+    async def process_group_write(self, telegram):
+        """Process incoming GROUP WRITE telegram."""
+        await self.switch.process(telegram)
 
     def __str__(self):
         """Return object as readable string."""
