@@ -1,4 +1,5 @@
 """Module for XKNX Exception handling."""
 # flake8: noqa
 from .exception import XKNXException, ConversionError, \
-    CouldNotParseTelegram, CouldNotParseKNXIP, CouldNotParseAddress
+    CouldNotParseTelegram, CouldNotParseKNXIP, CouldNotParseAddress, \
+    DeviceIllegalValue
