@@ -1,6 +1,6 @@
 """Abstraction to send DisconnectRequest and wait for DisconnectResponse."""
-from xknx.knxip import KNXIPServiceType, KNXIPFrame, HPAI,\
-    DisconnectResponse
+from xknx.knxip import HPAI, DisconnectResponse, KNXIPFrame, KNXIPServiceType
+
 from .request_response import RequestResponse
 
 
