@@ -6,14 +6,15 @@ KNXIPInterface manages KNX/IP Tunneling or Routing connections.
 * provides callbacks after having received a telegram from the network.
 
 """
-import asyncio
 from enum import Enum
-from xknx.exceptions import XKNXException
-from .gateway_scanner import GatewayScanner
+from platform import system as get_os_name
 
+from xknx.exceptions import XKNXException
+
+from .const import DEFAULT_MCAST_PORT
+from .gateway_scanner import GatewayScanFilter, GatewayScanner
 from .routing import Routing
 from .tunnel import Tunnel
-from .const import DEFAULT_MCAST_PORT
 
 
 class ConnectionType(Enum):
@@ -36,20 +37,33 @@ class ConnectionConfig:
     * local_ip: Local ip of the interface though which KNXIPInterface should connect.
     * gateway_ip: IP of KNX/IP tunneling device.
     * gateway_port: Port of KNX/IP tunneling device.
+    * auto_reconnect: Auto reconnect to KNX/IP tunneling device if connection cannot be established.
+    * auto_reconnect_wait: Wait n seconds before trying to reconnect to KNX/IP tunneling device.
+    * scan_filter: For AUTOMATIC connection, limit scan with the given filter
+    * bind_to_multicast_addr: Bind to the multicast address instead of the local IP (ROUTING only)
     """
 
-    # pylint: disable=too-few-public-methods
+    # pylint: disable=too-few-public-methods,too-many-instance-attributes
 
     def __init__(self,
-                 connection_type=ConnectionType.AUTOMATIC,
-                 local_ip=None,
-                 gateway_ip=None,
-                 gateway_port=DEFAULT_MCAST_PORT):
+                 connection_type: ConnectionType = ConnectionType.AUTOMATIC,
+                 local_ip: str = None,
+                 gateway_ip: str = None,
+                 gateway_port: int = DEFAULT_MCAST_PORT,
+                 auto_reconnect: bool = False,
+                 auto_reconnect_wait: int = 3,
+                 scan_filter: GatewayScanFilter = GatewayScanFilter(),
+                 bind_to_multicast_addr: bool = True):
         """Initialize ConnectionConfig class."""
+        # pylint: disable=too-many-arguments
         self.connection_type = connection_type
         self.local_ip = local_ip
         self.gateway_ip = gateway_ip
         self.gateway_port = gateway_port
+        self.auto_reconnect = auto_reconnect
+        self.auto_reconnect_wait = auto_reconnect_wait
+        self.scan_filter = scan_filter
+        self.bind_to_multicast_addr = bind_to_multicast_addr
 
 
 class KNXIPInterface():
@@ -61,40 +75,46 @@ class KNXIPInterface():
         self.interface = None
         self.connection_config = connection_config
 
-    @asyncio.coroutine
-    def start(self):
+    async def start(self):
         """Start interface. Connecting KNX/IP device with the selected method."""
         if self.connection_config.connection_type == ConnectionType.AUTOMATIC:
-            yield from self.start_automatic()
+            await self.start_automatic(
+                self.connection_config.scan_filter)
         elif self.connection_config.connection_type == ConnectionType.ROUTING:
-            yield from self.start_routing(
-                self.connection_config.local_ip)
+            await self.start_routing(
+                self.connection_config.local_ip,
+                self.connection_config.bind_to_multicast_addr)
         elif self.connection_config.connection_type == ConnectionType.TUNNELING:
-            yield from self.start_tunnelling(
+            await self.start_tunnelling(
                 self.connection_config.local_ip,
                 self.connection_config.gateway_ip,
-                self.connection_config.gateway_port)
+                self.connection_config.gateway_port,
+                self.connection_config.auto_reconnect,
+                self.connection_config.auto_reconnect_wait)
 
-    @asyncio.coroutine
-    def start_automatic(self):
+    async def start_automatic(self, scan_filter: GatewayScanFilter):
         """Start GatewayScanner and connect to the found device."""
-        gatewayscanner = GatewayScanner(self.xknx)
-        yield from gatewayscanner.start()
-        gatewayscanner.stop()
+        gatewayscanner = GatewayScanner(self.xknx, scan_filter=scan_filter)
+        gateways = await gatewayscanner.scan()
 
-        if not gatewayscanner.found:
+        if not gateways:
             raise XKNXException("No Gateways found")
 
-        if gatewayscanner.supports_tunneling:
-            yield from self.start_tunnelling(gatewayscanner.found_local_ip,
-                                             gatewayscanner.found_ip_addr,
-                                             gatewayscanner.found_port)
-        elif gatewayscanner.supports_routing:
-            yield from self.start_routing(gatewayscanner.found_local_ip)
+        gateway = gateways[0]
+        if gateway.supports_tunnelling:
+            await self.start_tunnelling(gateway.local_ip,
+                                        gateway.ip_addr,
+                                        gateway.port,
+                                        self.connection_config.auto_reconnect,
+                                        self.connection_config.auto_reconnect_wait)
+        elif gateway.supports_routing:
+            bind_to_multicast_addr = get_os_name() != "Darwin"  # = Mac OS
+            await self.start_routing(gateway.local_ip, bind_to_multicast_addr)
 
-    @asyncio.coroutine
-    def start_tunnelling(self, local_ip, gateway_ip, gateway_port):
+    async def start_tunnelling(self, local_ip, gateway_ip, gateway_port,
+                               auto_reconnect, auto_reconnect_wait):
         """Start KNX/IP tunnel."""
+        # pylint: disable=too-many-arguments
         self.xknx.logger.debug("Starting tunnel to %s:%s from %s", gateway_ip, gateway_port, local_ip)
         self.interface = Tunnel(
             self.xknx,
@@ -102,24 +122,25 @@ class KNXIPInterface():
             local_ip=local_ip,
             gateway_ip=gateway_ip,
             gateway_port=gateway_port,
-            telegram_received_callback=self.telegram_received)
-        yield from self.interface.start()
+            telegram_received_callback=self.telegram_received,
+            auto_reconnect=auto_reconnect,
+            auto_reconnect_wait=auto_reconnect_wait)
+        await self.interface.start()
 
-    @asyncio.coroutine
-    def start_routing(self, local_ip):
+    async def start_routing(self, local_ip, bind_to_multicast_addr):
         """Start KNX/IP Routing."""
         self.xknx.logger.debug("Starting Routing from %s", local_ip)
         self.interface = Routing(
             self.xknx,
             self.telegram_received,
-            local_ip)
-        yield from self.interface.start()
+            local_ip,
+            bind_to_multicast_addr)
+        await self.interface.start()
 
-    @asyncio.coroutine
-    def stop(self):
+    async def stop(self):
         """Stop connected interfae (either Tunneling or Routing)."""
         if self.interface is not None:
-            yield from self.interface.stop()
+            await self.interface.stop()
             self.interface = None
 
     def telegram_received(self, telegram):
@@ -127,7 +148,6 @@ class KNXIPInterface():
         self.xknx.loop.create_task(
             self.xknx.telegrams.put(telegram))
 
-    @asyncio.coroutine
-    def send_telegram(self, telegram):
+    async def send_telegram(self, telegram):
         """Send telegram to connected device (either Tunneling or Routing)."""
-        yield from self.interface.send_telegram(telegram)
+        await self.interface.send_telegram(telegram)
