@@ -4,6 +4,7 @@ Base class for sending a specific type of KNX/IP Packet to a KNX/IP device and w
 Will report if the corresponding answer was not received.
 """
 import asyncio
+
 from xknx.knxip import ErrorCode
 
 
@@ -27,19 +28,17 @@ class RequestResponse():
         """Create KNX/IP Frame object to be sent to device."""
         raise NotImplementedError('create_knxipframe has to be implemented')
 
-    @asyncio.coroutine
-    def start(self):
+    async def start(self):
         """Start. Sending and waiting for answer."""
         callb = self.udpclient.register_callback(
             self.response_rec_callback, [self.awaited_response_class.service_type])
-        yield from self.send_request()
-        yield from self.start_timeout()
-        yield from self.response_received_or_timeout.wait()
-        yield from self.stop_timeout()
+        await self.send_request()
+        await self.start_timeout()
+        await self.response_received_or_timeout.wait()
+        await self.stop_timeout()
         self.udpclient.unregister_callback(callb)
 
-    @asyncio.coroutine
-    def send_request(self):
+    async def send_request(self):
         """Build knxipframe (within derived class) and send via UDP."""
         knxipframe = self.create_knxipframe()
         knxipframe.normalize()
@@ -59,24 +58,21 @@ class RequestResponse():
 
     def on_success_hook(self, knxipframe):
         """Do something after having received a valid answer. May be overwritten in derived class."""
-        pass
+        self.xknx.logger.debug('Success: received correct answer from KNX bus: %s', knxipframe.body.status_code)
 
     def on_error_hook(self, knxipframe):
         """Do somthing after not having received valid answer within given time. May be overwritten in derived class."""
-        # pylint: disable=no-self-use
         self.xknx.logger.warning("Error: reading rading group address from KNX bus failed: %s", knxipframe.body.status_code)
 
     def timeout(self):
         """Handle timeout for not having received expected knxipframe."""
         self.response_received_or_timeout.set()
 
-    @asyncio.coroutine
-    def start_timeout(self):
+    async def start_timeout(self):
         """Start timeout."""
         self.timeout_handle = self.xknx.loop.call_later(
             self.timeout_in_seconds, self.timeout)
 
-    @asyncio.coroutine
-    def stop_timeout(self):
+    async def stop_timeout(self):
         """Stop timeout."""
         self.timeout_handle.cancel()
