@@ -3,17 +3,17 @@ Abstraction for handling KNX/IP routing.
 
 Routing uses UDP Multicast to broadcast and receive KNX/IP messages.
 """
-import asyncio
 from xknx.knx import TelegramDirection
-from xknx.knxip import KNXIPFrame, KNXIPServiceType, APCICommand
-from .udp_client import UDPClient
+from xknx.knxip import APCICommand, KNXIPFrame, KNXIPServiceType
+
 from .const import DEFAULT_MCAST_GRP, DEFAULT_MCAST_PORT
+from .udp_client import UDPClient
 
 
 class Routing():
     """Class for handling KNX/IP routing."""
 
-    def __init__(self, xknx, telegram_received_callback, local_ip):
+    def __init__(self, xknx, telegram_received_callback, local_ip, bind_to_multicast_addr):
         """Initialize Routing class."""
         self.xknx = xknx
         self.telegram_received_callback = telegram_received_callback
@@ -23,7 +23,7 @@ class Routing():
                                    (local_ip, 0),
                                    (DEFAULT_MCAST_GRP, DEFAULT_MCAST_PORT),
                                    multicast=True,
-                                   bind_to_multicast_addr=True)
+                                   bind_to_multicast_addr=bind_to_multicast_addr)
 
         self.udpclient.register_callback(
             self.response_rec_callback,
@@ -47,8 +47,7 @@ class Routing():
             if self.telegram_received_callback is not None:
                 self.telegram_received_callback(telegram)
 
-    @asyncio.coroutine
-    def send_telegram(self, telegram):
+    async def send_telegram(self, telegram):
         """Send Telegram to routing connected device."""
         knxipframe = KNXIPFrame(self.xknx)
         knxipframe.init(KNXIPServiceType.ROUTING_INDICATION)
@@ -56,19 +55,16 @@ class Routing():
         knxipframe.body.telegram = telegram
         knxipframe.body.sender = self.xknx.own_address
         knxipframe.normalize()
-        yield from self.send_knxipframe(knxipframe)
+        await self.send_knxipframe(knxipframe)
 
-    @asyncio.coroutine
-    def send_knxipframe(self, knxipframe):
+    async def send_knxipframe(self, knxipframe):
         """Send KNXIPFrame to connected routing device."""
         self.udpclient.send(knxipframe)
 
-    @asyncio.coroutine
-    def start(self):
+    async def start(self):
         """Start routing."""
-        yield from self.udpclient.connect()
+        await self.udpclient.connect()
 
-    @asyncio.coroutine
-    def stop(self):
+    async def stop(self):
         """Stop routing."""
-        yield from self.udpclient.stop()
+        await self.udpclient.stop()
