@@ -4,12 +4,14 @@ Abstraction for handling KNX/IP tunnels.
 Tunnels connect to KNX/IP devices directly via UDP and build a static UDP connection.
 """
 import asyncio
-from xknx.knx import TelegramDirection
-from xknx.knxip import TunnellingRequest, KNXIPFrame, KNXIPServiceType
+
 from xknx.exceptions import XKNXException
-from .disconnect import Disconnect
-from .connectionstate import ConnectionState
+from xknx.knx import TelegramDirection
+from xknx.knxip import KNXIPFrame, KNXIPServiceType, TunnellingRequest
+
 from .connect import Connect
+from .connectionstate import ConnectionState
+from .disconnect import Disconnect
 from .tunnelling import Tunnelling
 from .udp_client import UDPClient
 
@@ -19,7 +21,9 @@ class Tunnel():
 
     # pylint: disable=too-many-instance-attributes
 
-    def __init__(self, xknx, src_address, local_ip, gateway_ip, gateway_port, telegram_received_callback=None):
+    def __init__(self, xknx, src_address, local_ip, gateway_ip, gateway_port,
+                 telegram_received_callback=None, auto_reconnect=False,
+                 auto_reconnect_wait=3):
         """Initialize Tunnel class."""
         # pylint: disable=too-many-arguments
         self.xknx = xknx
@@ -36,6 +40,12 @@ class Tunnel():
         self.communication_channel = None
         self.number_heartbeat_failed = 0
 
+        self.auto_reconnect = auto_reconnect
+        self.auto_reconnect_wait = auto_reconnect_wait
+
+        self._heartbeat_task = None
+        self._reconnect_task = None
+
     def init_udp_client(self):
         """Initialize udp_client."""
         self.udp_client = UDPClient(self.xknx,
@@ -67,36 +77,41 @@ class Tunnel():
         ack_knxipframe.normalize()
         self.udp_client.send(ack_knxipframe)
 
-    @asyncio.coroutine
-    def start(self):
+    async def start(self):
         """Start tunneling."""
-        yield from self.connect_udp()
-        yield from self.connect()
+        await self.connect_udp()
+        await self.connect()
 
-    @asyncio.coroutine
-    def connect_udp(self):
+    async def connect_udp(self):
         """Connect udp_client."""
-        yield from self.udp_client.connect()
+        await self.udp_client.connect()
 
-    @asyncio.coroutine
-    def connect(self):
+    async def connect(self):
         """Connect/build tunnel."""
         connect = Connect(
             self.xknx,
             self.udp_client)
-        yield from connect.start()
+        await connect.start()
         if not connect.success:
+            if self.auto_reconnect:
+                msg = "Cannot connect to KNX. Retry in {} seconds.".format(
+                    self.auto_reconnect_wait
+                )
+                self.xknx.logger.warning(msg)
+                task = self.xknx.loop.create_task(self.schedule_reconnect())
+                self._reconnect_task = task
+                return
             raise XKNXException("Could not establish connection")
         self.xknx.logger.debug(
             "Tunnel established communication_channel=%s, id=%s",
             connect.communication_channel,
             connect.identifier)
+        self._reconnect_task = None
         self.communication_channel = connect.communication_channel
         self.sequence_number = 0
-        yield from self.start_heartbeat()
+        await self.start_heartbeat()
 
-    @asyncio.coroutine
-    def send_telegram(self, telegram):
+    async def send_telegram(self, telegram):
         """
         Send Telegram to routing tunelling device - retry mechanism.
 
@@ -111,20 +126,19 @@ class Tunnel():
         connection by sending a DISCONNECT_REQUEST frame to the other device’s
         control endpoint.
         """
-        success = yield from self._send_telegram_impl(telegram)
+        success = await self._send_telegram_impl(telegram)
         if not success:
             self.xknx.logger.warning("Sending of telegram failed. Retrying a second time.")
-            success = yield from self._send_telegram_impl(telegram)
+            success = await self._send_telegram_impl(telegram)
             if not success:
                 self.xknx.logger.warning("Resending telegram failed. Reconnecting to tunnel.")
-                yield from self.reconnect()
-                success = yield from self._send_telegram_impl(telegram)
+                await self.reconnect()
+                success = await self._send_telegram_impl(telegram)
                 if not success:
                     raise XKNXException("Could not send telegram to tunnel")
         self.increase_sequence_number()
 
-    @asyncio.coroutine
-    def _send_telegram_impl(self, telegram):
+    async def _send_telegram_impl(self, telegram):
         """Send Telegram to routing tunelling device - implementation."""
         tunnelling = Tunnelling(
             self.xknx,
@@ -133,7 +147,7 @@ class Tunnel():
             self.src_address,
             self.sequence_number,
             self.communication_channel)
-        yield from tunnelling.start()
+        await tunnelling.start()
         return tunnelling.success
 
     def increase_sequence_number(self):
@@ -142,74 +156,95 @@ class Tunnel():
         if self.sequence_number == 256:
             self.sequence_number = 0
 
-    @asyncio.coroutine
-    def connectionstate(self):
+    async def connectionstate(self):
         """Return state of tunnel. True if tunnel is in good shape."""
         conn_state = ConnectionState(
             self.xknx,
             self.udp_client,
             communication_channel_id=self.communication_channel)
-        yield from conn_state.start()
+        await conn_state.start()
         return conn_state.success
 
-    @asyncio.coroutine
-    def disconnect(self, ignore_error=False):
+    async def disconnect(self, ignore_error=False):
         """Disconnect from tunnel device."""
+        # only send disconnect request if we ever were connected
+        if self.communication_channel is None:
+            # close udp client to prevent open file descriptors
+            await self.udp_client.stop()
+            return
         disconnect = Disconnect(
             self.xknx,
             self.udp_client,
             communication_channel_id=self.communication_channel)
-        yield from disconnect.start()
+        await disconnect.start()
         if not disconnect.success and not ignore_error:
             raise XKNXException("Could not disconnect channel")
         else:
             self.xknx.logger.debug("Tunnel disconnected (communication_channel: %s)", self.communication_channel)
+        # close udp client to prevent open file descriptors
+        await self.udp_client.stop()
 
-    @asyncio.coroutine
-    def reconnect(self):
+    async def reconnect(self):
         """Reconnect to tunnel device."""
-        yield from self.disconnect(True)
+        await self.disconnect(True)
         self.init_udp_client()
-        yield from self.start()
+        await self.start()
 
-    @asyncio.coroutine
-    def stop(self):
+    async def schedule_reconnect(self):
+        """Schedule reconnect to KNX."""
+        await asyncio.sleep(self.auto_reconnect_wait)
+        await self.reconnect()
+
+    async def stop_reconnect(self):
+        """Stop reconnect task if running."""
+        if self._reconnect_task is not None:
+            self._reconnect_task.cancel()
+            self._reconnect_task = None
+
+    async def stop(self):
         """Stop tunneling."""
-        yield from self.disconnect()
-        yield from self.udp_client.stop()
+        # XXX: set disconnect ignore_error True here. Is there actually anything
+        #      which can happen if disconnect fails? normally this fails because
+        #      we have no connection...
+        # await self.disconnect()
+        await self.disconnect(True)
+        await self.stop_heartbeat()
+        await self.stop_reconnect()
 
-    @asyncio.coroutine
-    def start_heartbeat(self):
+    async def start_heartbeat(self):
         """Start heartbeat for monitoring state of tunnel, as suggested by 03.08.02 KNX Core 5.4."""
-        self.xknx.loop.create_task(
-            self.do_heartbeat())
+        self._heartbeat_task = self.xknx.loop.create_task(self.do_heartbeat())
 
-    @asyncio.coroutine
-    def do_heartbeat(self):
+    async def stop_heartbeat(self):
+        """Stop heartbeat task if running."""
+        if self._heartbeat_task is not None:
+            self._heartbeat_task.cancel()
+            self._heartbeat_task = None
+
+    async def do_heartbeat(self):
         """Heartbeat: Worker 'thread', endless loop for sending heartbeat requests."""
         while True:
-            yield from asyncio.sleep(15)
-            yield from self.do_heartbeat_impl()
+            await asyncio.sleep(15)
+            await self.do_heartbeat_impl()
 
-    @asyncio.coroutine
-    def do_heartbeat_impl(self):
+    async def do_heartbeat_impl(self):
         """Heartbeat: checking connection state and handling result."""
-        connectionsstate = yield from self.connectionstate()
+        connectionsstate = await self.connectionstate()
         if connectionsstate:
-            yield from self.do_heartbeat_success()
+            await self.do_heartbeat_success()
         else:
-            yield from self.do_heartbeat_failed()
+            await self.do_heartbeat_failed()
 
-    @asyncio.coroutine
-    def do_heartbeat_success(self):
+    async def do_heartbeat_success(self):
         """Heartbeat: handling success."""
         self.number_heartbeat_failed = 0
 
-    @asyncio.coroutine
-    def do_heartbeat_failed(self):
+    async def do_heartbeat_failed(self):
         """Heartbeat: handling error."""
         self.number_heartbeat_failed = self.number_heartbeat_failed + 1
         if self.number_heartbeat_failed > 3:
             self.xknx.logger.warning("Heartbeat failed - reconnecting")
-            yield from self.reconnect()
+            await self.stop_reconnect()
+            await self.reconnect()
             self.number_heartbeat_failed = 0
+            await self.stop_heartbeat()
