@@ -7,8 +7,8 @@ Due to lame support of UDP multicast within asyncio some special treatment for m
 import asyncio
 import socket
 
-from xknx.knxip import KNXIPFrame
 from xknx.exceptions import CouldNotParseKNXIP, XKNXException
+from xknx.knxip import KNXIPFrame
 
 
 class UDPClient:
@@ -55,12 +55,14 @@ class UDPClient:
                 self.data_received_callback(data)
 
         def error_received(self, exc):
-            """Handel errors. Callback for error received."""
-            self.xknx.logger.warning('Error received: %s', exc)
+            """Handle errors. Callback for error received."""
+            if hasattr(self, 'xknx'):
+                self.xknx.logger.warning('Error received: %s', exc)
 
         def connection_lost(self, exc):
             """Log error. Callback for connection lost."""
-            self.xknx.logger.info('closing transport %s', exc)
+            if hasattr(self, 'xknx'):
+                self.xknx.logger.info('closing transport %s', exc)
 
     def __init__(self, xknx, local_addr, remote_addr, multicast=False, bind_to_multicast_addr=False):
         """Initialize UDPClient class."""
@@ -137,7 +139,8 @@ class UDPClient:
 
         # I have no idea why we have to use different bind calls here
         # - bind() with multicast addr does not work with gateway search requests
-        #   on some machines. It only works if called with own ip.
+        #   on some machines. It only works if called with own ip. It also doesn't
+        #   work on Mac OS.
         # - bind() with own_ip does not work with ROUTING_INDICATIONS on Gira
         #   knx router - for an unknown reason.
         if bind_to_multicast_addr:
@@ -147,8 +150,7 @@ class UDPClient:
         sock.setsockopt(socket.IPPROTO_IP, socket.IP_MULTICAST_LOOP, 0)
         return sock
 
-    @asyncio.coroutine
-    def connect(self):
+    async def connect(self):
         """Connect UDP socket. Open UDP port and build mulitcast socket if necessary."""
         udp_client_factory = UDPClient.UDPClientFactory(
             self.xknx, self.local_addr[0], multicast=self.multicast,
@@ -156,12 +158,12 @@ class UDPClient:
 
         if self.multicast:
             sock = UDPClient.create_multicast_sock(self.local_addr[0], self.remote_addr, self.bind_to_multicast_addr)
-            (transport, _) = yield from self.xknx.loop.create_datagram_endpoint(
+            (transport, _) = await self.xknx.loop.create_datagram_endpoint(
                 lambda: udp_client_factory, sock=sock)
             self.transport = transport
 
         else:
-            (transport, _) = yield from self.xknx.loop.create_datagram_endpoint(
+            (transport, _) = await self.xknx.loop.create_datagram_endpoint(
                 lambda: udp_client_factory,
                 local_addr=self.local_addr,
                 remote_addr=self.remote_addr)
@@ -188,7 +190,6 @@ class UDPClient:
         peer = self.transport.get_extra_info('peername')
         return peer
 
-    @asyncio.coroutine
-    def stop(self):
+    async def stop(self):
         """Stop UDP socket."""
         self.transport.close()
