@@ -1,9 +1,45 @@
 """Implementation of Basic KNX datatypes."""
+from enum import Enum
+
 from xknx.exceptions import ConversionError
 
 
 class DPTBase:
-    """Base class for KNX data types."""
+    """
+    Base class for KNX data types.
+
+    KNX communicates using Group-addresses, and every Group Object represents a data point of some type.
+    To have a standardized interpretation of the data there are a number of Data Point types (DPT).
+    The DPT's is written like: xx.yyy, for example 14.056 for a 4-octet float, with Power info in Watts.
+    The Major number (xx) describes the data type (format and encoding) - while the the minor (YYY) number
+    describes the measurement with value range and unit.
+
+    More DTP's are added as new needs come up, but this a list of some of the commonly used ones:
+    1.yyy  boolean, like switching, on/off, open/close, move up/down, step
+    2.yyy  2 x boolean, e.g. switching + priority control
+    3.yyy  boolean + 3-bit unsigned value, e.g. dimming up/down
+    4.yyy  character (8-bit)
+    5.yyy  8-bit unsigned value, like dim value (0..100%), blinds position (0..100%)
+    6.yyy  8-bit signed (2's complement), e.g. +/- %
+    7.yyy  2-byte unsigned value, i.e. pulse counter
+    8.yyy  2-byte signed (2's complement), e.g. +/- %
+    9.yyy  2-byte float, e.g. temperature
+    10.yyy time (3 bytes)
+    11.yyy date (3 bytes)
+    12.yyy 4-byte unsigned value, i.e. pulse counter
+    13.yyy 4-byte signed (2's complement), i.e. flow, energy
+    14.yyy 4-byte float, IEEE 754, i.e. Electrical measurements: current, power
+    15.yyy access control
+    16.yyy string -> 14 characters (14 x 8-bit)
+    17.yyy scene number
+    18.yyy scene control
+    19.yyy date / time
+    20.yyy 8-bit enumeration, e.g. HVAC mode ('auto', 'comfort', 'standby', 'economy', 'protection')
+    28.yyy UTF-8
+    29.yyy V64, 64-bit signed value
+    232.yyy RGB [0,0,0]...[255,255,255]
+
+    """
 
     # pylint: disable=too-few-public-methods
     @staticmethod
@@ -14,7 +50,7 @@ class DPTBase:
                 or any(not isinstance(byte, int) for byte in raw) \
                 or any(byte < 0 for byte in raw) \
                 or any(byte > 255 for byte in raw):
-            raise ConversionError(raw)
+            raise ConversionError("Invalid raw bytes", raw=raw)
 
 
 class DPTBinary(DPTBase):
@@ -31,7 +67,7 @@ class DPTBinary(DPTBase):
         if not isinstance(value, int):
             raise TypeError()
         if value > DPTBinary.APCI_BITMASK:
-            raise ConversionError(value)
+            raise ConversionError("Cant init DPTBinary", value=value)
 
         self.value = value
 
@@ -81,28 +117,41 @@ class DPTComparator():
         if a is None and b is None:
             return True
 
-        elif a is None:
+        if a is None:
             if isinstance(b, DPTBinary):
                 return b.value == 0
-            elif isinstance(b, DPTArray):
+            if isinstance(b, DPTArray):
                 return len(b.value) == 0
 
-        elif b is None:
+        if b is None:
             if isinstance(a, DPTBinary):
                 return a.value == 0
-            elif isinstance(a, DPTArray):
+            if isinstance(a, DPTArray):
                 return len(a.value) == 0
 
-        elif isinstance(a, DPTArray) and isinstance(b, DPTArray):
+        if isinstance(a, DPTArray) and isinstance(b, DPTArray):
             return a.value == b.value
 
-        elif isinstance(a, DPTBinary) and isinstance(b, DPTBinary):
+        if isinstance(a, DPTBinary) and isinstance(b, DPTBinary):
             return a.value == b.value
 
-        elif isinstance(a, DPTBinary) and isinstance(b, DPTArray):
+        if isinstance(a, DPTBinary) and isinstance(b, DPTArray):
             return a.value == 0 and len(b.value) == 0
 
-        elif isinstance(a, DPTArray) and isinstance(b, DPTBinary):
+        if isinstance(a, DPTArray) and isinstance(b, DPTBinary):
             return len(a.value) == 0 and b.value == 0
 
         raise TypeError()
+
+
+class DPTWeekday(Enum):
+    """Enum class for week days."""
+
+    MONDAY = 1
+    TUESDAY = 2
+    WEDNESDAY = 3
+    THURSDAY = 4
+    FRIDAY = 5
+    SATURDAY = 6
+    SUNDAY = 7
+    NONE = 0
