@@ -1,20 +1,24 @@
-"""Implementation of Basic KNX 2-Byte."""
+"""Implementation of Basic KNX 2-Byte/octet values."""
 
 from xknx.exceptions import ConversionError
+
 from .dpt import DPTBase
 
 
-class DPT2Byte(DPTBase):
+class DPT2ByteUnsigned(DPTBase):
     """
-    Abstraction for KNX 2 Byte "2-octet unsigned counter value".
+    Abstraction for KNX 2 Byte "2-octet unsigned value".
 
-    DPT 7.001
+    Contains smaller counters, timers  etc.
+
+    DPT 7.xxx
     """
 
     value_min = 0
     value_max = 65535
-    unit = "pulses"
+    unit = ""
     resolution = 1
+    payload_length = 2
 
     @classmethod
     def from_knx(cls, raw):
@@ -26,24 +30,28 @@ class DPT2Byte(DPTBase):
     def to_knx(cls, value):
         """Serialize to KNX/IP raw data."""
         if not cls._test_boundaries(value):
-            raise ConversionError(value)
+            raise ConversionError("Cant serialize DPT2ByteUnsigned", value=value)
         return value >> 8, value & 0xff
 
     @classmethod
     def _test_boundaries(cls, value):
         """Test if value is within defined range for this object."""
-        return value >= cls.value_min and \
-            value <= cls.value_max
+        return cls.value_min <= value <= cls.value_max
 
 
-class DPTUElCurrentmA(DPT2Byte):
-    """
-    Abstraction for KNX 2 Byte DPTUElCurrentmA.
+class DPT2Ucount(DPT2ByteUnsigned):
+    """DPT 7.001 DPT_Value_2_Ucount."""
 
-    DPT 7.012
-    """
+    unit = "pulses"
+
+
+class DPTUElCurrentmA(DPT2ByteUnsigned):
+    """DPT 7.012 Abstraction for KNX 2 Byte DPTUElCurrentmA."""
 
-    value_min = 0
-    value_max = 65535
     unit = "mA"
-    resolution = 1
+
+
+class DPTBrightness(DPT2ByteUnsigned):
+    """DPT 7.013 DPT_Brightness (lux)."""
+
+    unit = "lx"
