@@ -1,6 +1,7 @@
 """Implementation of Basic KNX 2-Byte."""
 
 from xknx.exceptions import ConversionError
+
 from .dpt import DPTBase
 
 
@@ -27,7 +28,7 @@ class DPTSignedRelativeValue(DPTBase):
     def to_knx(cls, value):
         """Serialize to KNX/IP raw data."""
         if not cls._test_boundaries(value):
-            raise ConversionError(value)
+            raise ConversionError("Cant serialize DPTSignedRelativeValue", value=value)
         if value < 0:
             value += 0x100
         return (value & 0xff,)
@@ -35,8 +36,7 @@ class DPTSignedRelativeValue(DPTBase):
     @classmethod
     def _test_boundaries(cls, value):
         """Test if value is within defined range for this object."""
-        return value >= cls.value_min and \
-            value <= cls.value_max
+        return cls.value_min <= value <= cls.value_max
 
 
 class DPTPercentV8(DPTSignedRelativeValue):
