@@ -15,7 +15,8 @@ It contains
 
 """
 from enum import Enum
-from .address import Address
+
+from .address import GroupAddress
 
 
 class TelegramDirection(Enum):
@@ -38,7 +39,7 @@ class Telegram:
 
     # pylint: disable=too-few-public-methods
 
-    def __init__(self, group_address=Address(),
+    def __init__(self, group_address=GroupAddress(None),
                  telegramtype=TelegramType.GROUP_WRITE,
                  direction=TelegramDirection.OUTGOING,
                  payload=None):
@@ -52,7 +53,7 @@ class Telegram:
         """Return object as readable string."""
         return '<Telegram group_address="{0}", payload="{1}" ' \
             'telegramtype="{2}" direction="{3}" />'.format(
-                self.group_address,
+                self.group_address.__repr__(),
                 self.payload,
                 self.telegramtype,
                 self.direction)
