@@ -12,11 +12,11 @@ Documentation within:
     File: AN117 v02.01 KNX IP Communication Medium DV.pdf
 """
 from xknx.exceptions import ConversionError, CouldNotParseKNXIP
-from xknx.knx import Address, AddressType, DPTBinary, DPTArray, \
-    Telegram, TelegramType
+from xknx.knx import (
+    DPTArray, DPTBinary, GroupAddress, PhysicalAddress, Telegram, TelegramType)
 
-from .knxip_enum import CEMIMessageCode, APCICommand, CEMIFlags
 from .body import KNXIPBody
+from .knxip_enum import APCICommand, CEMIFlags, CEMIMessageCode
 
 
 class CEMIFrame(KNXIPBody):
@@ -30,8 +30,8 @@ class CEMIFrame(KNXIPBody):
         self.code = CEMIMessageCode.L_DATA_IND
         self.flags = 0
         self.cmd = APCICommand.GROUP_READ
-        self.src_addr = Address()
-        self.dst_addr = Address()
+        self.src_addr = GroupAddress(None)
+        self.dst_addr = GroupAddress(None)
         self.mpdu_len = 0
         self.payload = None
 
@@ -46,12 +46,11 @@ class CEMIFrame(KNXIPBody):
             """Return telegram type from APCI Command."""
             if cmd == APCICommand.GROUP_WRITE:
                 return TelegramType.GROUP_WRITE
-            elif cmd == APCICommand.GROUP_READ:
+            if cmd == APCICommand.GROUP_READ:
                 return TelegramType.GROUP_READ
-            elif cmd == APCICommand.GROUP_RESPONSE:
+            if cmd == APCICommand.GROUP_RESPONSE:
                 return TelegramType.GROUP_RESPONSE
-            else:
-                raise ConversionError("Telegram not implemented for {0}".format(self.cmd))
+            raise ConversionError("Telegram not implemented for {0}".format(self.cmd))
 
         telegram.telegramtype = resolve_telegram_type(self.cmd)
 
@@ -80,12 +79,11 @@ class CEMIFrame(KNXIPBody):
             """Resolve APCICommand from TelegramType."""
             if telegramtype == TelegramType.GROUP_READ:
                 return APCICommand.GROUP_READ
-            elif telegramtype == TelegramType.GROUP_WRITE:
+            if telegramtype == TelegramType.GROUP_WRITE:
                 return APCICommand.GROUP_WRITE
-            elif telegramtype == TelegramType.GROUP_RESPONSE:
+            if telegramtype == TelegramType.GROUP_RESPONSE:
                 return APCICommand.GROUP_RESPONSE
-            else:
-                raise TypeError()
+            raise TypeError()
         self.cmd = resolve_cmd(telegram.telegramtype)
 
     def set_hops(self, hops):
@@ -99,12 +97,11 @@ class CEMIFrame(KNXIPBody):
         """Get length of KNX/IP body."""
         if self.payload is None:
             return 11
-        elif isinstance(self.payload, DPTBinary):
+        if isinstance(self.payload, DPTBinary):
             return 11
-        elif isinstance(self.payload, DPTArray):
+        if isinstance(self.payload, DPTArray):
             return 11 + len(self.payload.value)
-        else:
-            raise TypeError()
+        raise TypeError()
 
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
@@ -114,8 +111,7 @@ class CEMIFrame(KNXIPBody):
                 self.code == CEMIMessageCode.L_Data_REQ or \
                 self.code == CEMIMessageCode.L_DATA_CON:
             return self.from_knx_data_link_layer(raw)
-        else:
-            raise CouldNotParseKNXIP("Could not understand CEMIMessageCode: {0} / {1}".format(self.code, raw[0]))
+        raise CouldNotParseKNXIP("Could not understand CEMIMessageCode: {0} / {1}".format(self.code, raw[0]))
 
     def from_knx_data_link_layer(self, cemi):
         """Parse L_DATA_IND, CEMIMessageCode.L_Data_REQ, CEMIMessageCode.L_DATA_CON."""
@@ -129,16 +125,13 @@ class CEMIFrame(KNXIPBody):
 
         self.flags = cemi[2 + addil] * 256 + cemi[3 + addil]
 
-        self.src_addr = Address((cemi[4 + addil], cemi[5 + addil]),
-                                AddressType.PHYSICAL)
+        self.src_addr = PhysicalAddress((cemi[4 + addil], cemi[5 + addil]))
 
         if self.flags & CEMIFlags.DESTINATION_GROUP_ADDRESS:
-            self.dst_addr = Address((cemi[6 + addil], cemi[7 + addil]),
-                                    address_type=AddressType.GROUP,
-                                    address_format=self.xknx.address_format)
+            self.dst_addr = GroupAddress((cemi[6 + addil], cemi[7 + addil]),
+                                         levels=self.xknx.address_format)
         else:
-            self.dst_addr = Address((cemi[6 + addil], cemi[7 + addil]),
-                                    address_type=AddressType.PHYSICAL)
+            self.dst_addr = PhysicalAddress((cemi[6 + addil], cemi[7 + addil]))
 
         self.mpdu_len = cemi[8 + addil]
 
@@ -165,9 +158,9 @@ class CEMIFrame(KNXIPBody):
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
-        if not isinstance(self.src_addr, Address):
+        if not isinstance(self.src_addr, (GroupAddress, PhysicalAddress)):
             raise ConversionError("src_add not set")
-        if not isinstance(self.dst_addr, Address):
+        if not isinstance(self.dst_addr, (GroupAddress, PhysicalAddress)):
             raise ConversionError("dst_add not set")
 
         data = []
@@ -209,8 +202,12 @@ class CEMIFrame(KNXIPBody):
         """Return object as readable string."""
         return '<CEMIFrame SourceAddress="{0}" DestinationAddress="{1}" ' \
                'Flags="{2:16b}" Command="{3}" payload="{4}" />'.format(
-                   self.src_addr,
-                   self.dst_addr,
+                   self.src_addr.__repr__(),
+                   self.dst_addr.__repr__(),
                    self.flags,
                    self.cmd,
                    self.payload)
+
+    def __eq__(self, other):
+        """Equal operator."""
+        return self.__dict__ == other.__dict__
