@@ -12,8 +12,9 @@ A KNX/IP Search Response may contain several DIBs of different types:
 """
 
 from xknx.exceptions import CouldNotParseKNXIP
-from xknx.knx import Address, AddressType
-from .knxip_enum import DIBTypeCode, KNXMedium, DIBServiceFamily
+from xknx.knx import PhysicalAddress
+
+from .knxip_enum import DIBServiceFamily, DIBTypeCode, KNXMedium
 
 
 class DIB():
@@ -26,19 +27,15 @@ class DIB():
 
     def __init__(self):
         """Initialize DIB class."""
-        pass
 
     def calculated_length(self):
         """Get length of KNX/IP object."""
-        pass
 
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
-        pass
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
-        pass
 
     @staticmethod
     def determine_dib(raw):
@@ -49,7 +46,7 @@ class DIB():
 
         if dtc == DIBTypeCode.DEVICE_INFO:
             return DIBDeviceInformation()
-        elif dtc == DIBTypeCode.SUPP_SVC_FAMILIES:
+        if dtc == DIBTypeCode.SUPP_SVC_FAMILIES:
             return DIBSuppSVCFamilies()
         return DIBGeneric()
 
@@ -97,9 +94,9 @@ class DIBGeneric(DIB):
 
     def __str__(self):
         """Return object as readable string."""
-        return '<DIB dtc="{0}" data="\'{1}\'" />'.format(
+        return '<DIB dtc="{0}" data="{1}" />'.format(
             self.dtc,
-            ','.join('0x%02x' % i for i in self.data))
+            ', '.join('0x%02x' % i for i in self.data))
 
 
 class DIBSuppSVCFamilies(DIB):
@@ -169,7 +166,7 @@ class DIBSuppSVCFamilies(DIB):
     def __str__(self):
         """Return object as readable string."""
         return '<DIBSuppSVCFamilies families="[{0}]" />' \
-            .format(", ".join("\n\t{0} version: {1}".format(
+            .format(", ".join("{0} version: {1}".format(
                 family.name, family.version) for family in self.families))
 
 
@@ -185,7 +182,7 @@ class DIBDeviceInformation(DIB):
         super(DIBDeviceInformation, self).__init__()
         self.knx_medium = KNXMedium.TP1
         self.programming_mode = False
-        self.individual_address = Address()
+        self.individual_address = PhysicalAddress(None)
         self.installation_number = 0
         self.project_number = 0
         self.serial_number = ""
@@ -210,7 +207,7 @@ class DIBDeviceInformation(DIB):
         # last bit of device_status. All other bits are unused
         self.programming_mode = bool(raw[3])
         self.individual_address = \
-            Address((raw[4], raw[5]), AddressType.PHYSICAL)
+            PhysicalAddress((raw[4], raw[5]))
         installation_project_identifier = raw[6]*256+raw[7]
         self.project_number = installation_project_identifier >> 4
         self.installation_number = installation_project_identifier & 15
