@@ -1,7 +1,8 @@
 """Module for serialization and deserialization of KNX/IP Header."""
 from xknx.exceptions import CouldNotParseKNXIP
-from .knxip_enum import KNXIPServiceType
+
 from .body import KNXIPBody
+from .knxip_enum import KNXIPServiceType
 
 
 class KNXIPHeader():
@@ -62,3 +63,7 @@ class KNXIPHeader():
                 self.service_type_ident,
                 self.b4_reserve,
                 self.total_length)
+
+    def __eq__(self, other):
+        """Equal operator."""
+        return self.__dict__ == other.__dict__
