@@ -5,19 +5,20 @@ It consists of a header and a body.
 Depending on the service_type_ident different types of body classes are instanciated.
 """
 from xknx.exceptions import CouldNotParseKNXIP
-from .knxip_enum import KNXIPServiceType
-from .header import KNXIPHeader
+
 from .cemi_frame import CEMIFrame
 from .connect_request import ConnectRequest
 from .connect_response import ConnectResponse
-from .tunnelling_request import TunnellingRequest
-from .tunnelling_ack import TunnellingAck
-from .search_request import SearchRequest
-from .search_response import SearchResponse
-from .disconnect_request import DisconnectRequest
-from .disconnect_response import DisconnectResponse
 from .connectionstate_request import ConnectionStateRequest
 from .connectionstate_response import ConnectionStateResponse
+from .disconnect_request import DisconnectRequest
+from .disconnect_response import DisconnectResponse
+from .header import KNXIPHeader
+from .knxip_enum import KNXIPServiceType
+from .search_request import SearchRequest
+from .search_response import SearchResponse
+from .tunnelling_ack import TunnellingAck
+from .tunnelling_request import TunnellingRequest
 
 
 class KNXIPFrame:
@@ -96,3 +97,7 @@ class KNXIPFrame:
         """Return object as readable string."""
         return '<KNXIPFrame {0}\n body="{1}" />' \
             .format(self.header, self.body)
+
+    def __eq__(self, other):
+        """Equal operator."""
+        return self.__dict__ == other.__dict__
